"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeScriptResourcesPlugin = void 0;
const globby_1 = __importDefault(require("globby"));
const path = __importStar(require("path"));
const webpack_inject_plugin_1 = __importDefault(require("webpack-inject-plugin"));
const helpers_1 = require("../webpack/helpers");
class TypeScriptResourcesPlugin {
    constructor() {
        this.resourcesMap = {};
        this.entryName = 'ts-resources';
        const config = helpers_1.getJSONFile('config/config.json');
        const localizedResources = config.localizedResources;
        for (const resourceKey in localizedResources) {
            const resourcePath = localizedResources[resourceKey];
            const search = resourcePath.replace(/^lib/gi, 'src').replace('{locale}.js', '*.ts');
            const exclude = '!' + search.replace('*.ts', '*.d.ts');
            const typescriptResources = globby_1.default.sync([search, exclude], {
                cwd: process.cwd()
            });
            if (!(typescriptResources === null || typescriptResources === void 0 ? void 0 : typescriptResources.length)) {
                continue;
            }
            for (const resourcePath of typescriptResources) {
                const key = helpers_1.createKeyFromPath(resourcePath);
                const fileName = `${resourceKey}_${path.basename(resourcePath).replace('.ts', '.js')}`;
                this.resourcesMap[key] = {
                    path: helpers_1.trimLeft(resourcePath, '/\\\\'),
                    fileName
                };
            }
        }
    }
    apply(compiler) {
        const allKeys = Object.keys(this.resourcesMap);
        if (!(allKeys === null || allKeys === void 0 ? void 0 : allKeys.length)) {
            return;
        }
        compiler.options.entry[this.entryName] = './src/index';
        const tsLoader = compiler.options.module.rules[0].use[0];
        compiler.options.module.rules[0].use = [
            {
                loader: require.resolve('./TypeScriptResourcesLoader'),
                options: this.resourcesMap
            },
            Object.assign({}, tsLoader)
        ];
        new webpack_inject_plugin_1.default(this.createInjectFunction(), {
            entryName: this.entryName
        }).apply(compiler);
    }
    createInjectFunction() {
        const template = 'require("###");';
        return () => {
            let result = '';
            for (const key in this.resourcesMap) {
                const map = this.resourcesMap[key];
                result += template.replace('###', './' + map.path);
            }
            return result;
        };
    }
}
exports.TypeScriptResourcesPlugin = TypeScriptResourcesPlugin;
//# sourceMappingURL=TypeScriptResourcesPlugin.js.map